@@ -20,6 +20,8 @@ from tempor.utils import (
     rm_hosts,
     save_hosts,
     terraform_installed,
+    TF_IMAGES,
+    ALL_IMAGES
 )
 from tempor.playbook import run_playbook
 
@@ -30,9 +32,30 @@ def get_args():
     if not cfg:
         sys.exit(1)
 
-    if "default" in cfg:
+    # If we have a default provider and image set
+    if "default" in cfg and "image" in cfg:
         provider = cfg["default"]
 
+        try:
+            p = TF_IMAGES[provider][cfg['image']]
+            
+            if 'image' in p:
+                image = p['image']
+            else:
+                image = p
+
+            user = p['user'] if 'user' in p else 'root'
+
+        except KeyError as e:
+            console.print(f"[red bold]Unsupported Image ({cfg['image']}) for provider ({provider})")
+            sys.exit(1)
+        images = TF_IMAGES[provider]
+    else:
+        provider = None
+        image = None
+        images = ALL_IMAGES
+
+
     parser = argparse.ArgumentParser()
     parser.add_argument(
         "-p",
@@ -41,13 +64,23 @@ def get_args():
         choices=os.listdir(f"{ROOT_DIR}/providers"),
         help="Specify the Provider Name",
     )
+    parser.add_argument(
+        "-i",
+        "--image",
+        default=image,
+        choices=images,
+        help="Specify the OS Image",
+    )
     parser.add_argument(
         "-c", "--count", default=1, type=int, help="Number of VPS' to Create"
     )
-    parser.add_argument("--setup", action="store_true", help="Create VPS'")
-    parser.add_argument("--list", action="store_true", help="List Available VPS'")
+    parser.add_argument("-s", "--setup", action="store_true", help="Create VPS'")
+    parser.add_argument("-l", "--list", action="store_true", help="List Available VPS'")
     parser.add_argument(
-        "--no-config", action="store_true", help="Leave as a Bare Install"
+        "-b", "--bare", action="store_true", help="Leave as a Bare Install"
+    )
+    parser.add_argument(
+        "-m", "--minimal", action="store_true", help="Minimal Configuration"
     )
     parser.add_argument("--teardown", action="store_true", help="Tear down VPS'")
 
@@ -58,6 +91,10 @@ def get_args():
         console.print("[red bold]Must Specify a Provider")
         sys.exit(1)
 
+    if not args.image:
+        console.print("[red bold]Must Specify an Image")
+        sys.exit(1)
+
     provider = args.provider
     if "providers" in cfg:
         # lets check for the API token
@@ -73,6 +110,21 @@ def get_args():
         console.print("[red bold]Providers are required")
         sys.exit(1)
 
+    try:
+        p = TF_IMAGES[provider][args.image]
+        
+        if 'image' in p:
+            args.image = p['image']
+        else:
+            args.image = p
+
+        args.user = p['user'] if 'user' in p else 'root'
+
+    except KeyError as e:
+        console.print(f"[red bold]Unsupported Image ({args.image}) for provider ({provider})")
+        sys.exit(1)
+
+
     return (provider, api_token, args)
 
 
@@ -99,7 +151,11 @@ def main():
     # now what do we want to do?
     if args.teardown:
         console.print("Tearing down...", end="", style="bold italic")
-        ret, stdout, stderr = t.cmd("apply", "-destroy", "-auto-approve", var={"api_token": api_token})
+        ret, stdout, stderr = t.cmd("apply", "-destroy", "-auto-approve", 
+                                var={
+                                    "api_token": api_token,
+                                    "image": args.image
+                                })
         if ret != 0 and stderr:
             console.print("[red bold]Failed during Teardown")
             console.print(f"[red bold]{stderr}")
@@ -130,7 +186,7 @@ def main():
     # lets plan the config
     console.print("Preparing Configuration...", end="", style="bold italic")
     ret, stdout, stderr = t.cmd(
-        "plan", f"-out={plan_path}", var={"api_token": api_token, "num": args.count}
+            "plan", f"-out={plan_path}", var={"api_token": api_token, "num": args.count, "image": args.image}
     )
     if ret != 0 and stderr:
         console.print("[red bold]Failed during Planning")
@@ -150,32 +206,32 @@ def main():
     console.print("Configuring SSH Keys...", end="", style="bold italic")
     # Get Hostname and IP Adress
     output = t.output()
-    print(output)
 
     new_hosts = dict()
     # digitalocean
     if "droplet_ip_address" in output:
         for hostname, ip_address in output["droplet_ip_address"]["value"].items():
             new_hosts[hostname] = ip_address
-            install_ssh_keys(provider, hostname, ip_address)
+            install_ssh_keys(provider, hostname, ip_address, args.user)
 
     # linode, aws
     elif "instance_ip_address" in output:
         for hostname, ip_address in output["instance_ip_address"]["value"].items():
             new_hosts[hostname] = ip_address
-            install_ssh_keys(provider, hostname, ip_address)
+            install_ssh_keys(provider, hostname, ip_address, args.user)
 
     # vultr
     elif "server_ip_address" in output:
         for hostname, ip_address in output["server_ip_address"]["value"].items():
             new_hosts[hostname] = ip_address
-            install_ssh_keys(provider, hostname, ip_address)
+            install_ssh_keys(provider, hostname, ip_address, args.user)
     console.print("Done.")
 
     save_hosts(provider, new_hosts)
 
-    if not args.no_config:
-        run_playbook()
+    if not args.bare:
+        playbook = 'minimal.yml' if args.minimal else 'main.yml'
+        run_playbook(playbook, args.user)
 
     console.print("\nVPS' now available!\n", style="bold italic green")
     for host in new_hosts:
